#[non_exhaustive]pub enum IdOutOfBounds {
UsizeOverflow,
OutOfRange {
slot: usize,
count: usize,
},
}Expand description
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UsizeOverflow
The ID’s value did not fit in usize on the current target.
OutOfRange
The ID’s slot was greater than or equal to the dense count.