OffsetIntegrityIssue

Enum OffsetIntegrityIssue 

#[non_exhaustive]
pub enum OffsetIntegrityIssue { Length { expected: usize, actual: usize, }, CountOverflow { count: usize, }, FirstNonZero { actual: usize, }, NonMonotonic { index: usize, previous: usize, actual: usize, }, FinalMismatch { final_offset: usize, value_len: usize, }, ValueOutOfRange { index: usize, value: usize, bound: usize, }, UsizeOverflow { index: usize, }, }
Reasons a borrowed offset or value array failed structural validation.

Performance

Formatting is O(message length).

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Length

Length did not match count + 1.

Fields

expected: usize

Expected length (count + 1).

actual: usize

Observed length.



CountOverflow

expected_count + 1 overflowed usize, so no valid length exists.

Fields

count: usize

The element count whose successor overflowed.



FirstNonZero

offsets[0] was not zero.

Fields

actual: usize

Observed first offset.



NonMonotonic

offsets[index] < offsets[index - 1].

Fields

index: usize

Index where monotonicity failed.

previous: usize

Offset at index - 1.

actual: usize

Offset at index.



FinalMismatch

offsets[count] did not match value_len.

Fields

final_offset: usize

Observed final offset.

value_len: usize

Length of the values array.



ValueOutOfRange

A value at index was not less than the dense bound.

Fields

index: usize

Index of the offending value.

value: usize

Observed value.

bound: usize

Exclusive upper bound.



UsizeOverflow

A word’s value at index did not fit in usize on the current target.

Fields

index: usize

Slice position of the offending word.