#[non_exhaustive]pub enum OffsetOverflow {
IndexOverflow {
value: usize,
},
}Expand description
Reasons a usize could not be represented in a target index width during
builder offset construction.
Performance
Formatting is O(message length).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IndexOverflow
A usize value did not fit in the target LayoutIndex width.