IdOutOfBounds

Enum IdOutOfBounds 

#[non_exhaustive]
pub enum IdOutOfBounds { UsizeOverflow, OutOfRange { slot: usize, count: usize, }, }
Reasons an ID failed dense bounds validation.

Performance

Formatting is O(message length).

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UsizeOverflow

The ID’s value did not fit in usize on the current target.



OutOfRange

The ID’s slot was greater than or equal to the dense count.

Fields

slot: usize

Slot derived from the ID.

count: usize

Exclusive upper bound for the slot.