#[non_exhaustive]pub enum OffsetIntegrityIssue {
Length {
expected: usize,
actual: usize,
},
CountOverflow {
count: usize,
},
FirstNonZero {
actual: usize,
},
NonMonotonic {
index: usize,
previous: usize,
actual: usize,
},
FinalMismatch {
final_offset: usize,
value_len: usize,
},
ValueOutOfRange {
index: usize,
value: usize,
bound: usize,
},
UsizeOverflow {
index: usize,
},
}Expand description
Reasons a borrowed offset or value array failed structural validation.
Performance
Formatting is O(message length).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Length
Length did not match count + 1.
CountOverflow
expected_count + 1 overflowed usize, so no valid length exists.
FirstNonZero
offsets[0] was not zero.
NonMonotonic
offsets[index] < offsets[index - 1].
Fields
FinalMismatch
offsets[count] did not match value_len.
ValueOutOfRange
A value at index was not less than the dense bound.
Fields
UsizeOverflow
A word’s value at index did not fit in usize on the current target.